Vrm0ColliderGroup class final

One legacy VRM 0.x collider group.

Properties

colliders List<Vrm0Collider>
Sphere colliders in source array order.
final
hashCode int
The hash code for this object.
no setterinherited
node int?
glTF node that owns this collider group.
final
raw Map<String, Object?>
Original legacy collider-group JSON object.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceIndex int
Index of this entry in the source colliderGroups array.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited