Vrm0MeshAnnotation class final

One legacy VRM 0.x first-person mesh annotation.

Properties

firstPersonFlag String?
Raw legacy visibility flag.
final
hashCode int
The hash code for this object.
no setterinherited
mesh int?
Target glTF mesh index.
final
raw Map<String, Object?>
Original legacy mesh-annotation JSON object.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceIndex int
Index of this entry in the source meshAnnotations array.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited