VrmExpression class final

One VRM expression definition.

Properties

hashCode int
The hash code for this object.
no setterinherited
isBinary bool
Whether input weights are thresholded to 0 or 1.
final
materialColorBinds List<VrmMaterialColorBind>
Material color binds.
final
morphTargetBinds List<VrmMorphTargetBind>
Morph target binds.
final
name String
Raw expression name.
final
Blink override behavior.
final
overrideLookAt VrmExpressionOverrideMode
LookAt-expression override behavior.
final
overrideMouth VrmExpressionOverrideMode
Lip-sync override behavior.
final
raw Map<String, Object?>
Raw expression object, preserved.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textureTransformBinds List<VrmTextureTransformBind>
Texture transform binds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited