VrmExpressionController class final

Controls VRM expression input and application.

Constructors

VrmExpressionController(VrmModel model)
Creates an expression controller for model.

Properties

hashCode int
The hash code for this object.
no setterinherited
model VrmModel
Parsed model backing this controller.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyTo(VrmSceneBinding binding) → void
Applies evaluated expression binds to binding.
clear() → void
Clears application-set expression inputs.
evaluate() Map<String, double>
Evaluates clamping, binary output, and procedural override rules.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCustom(String name, double weight) → void
Sets a custom expression input weight.
setLipSync(VrmLipSyncPreset preset, double weight) → void
Sets a lip-sync expression input weight.
setPreset(VrmExpressionPreset preset, double weight) → void
Sets a preset expression input weight.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited