VrmFirstPerson class final

VRM first-person settings.

Properties

firstPersonBone int?
Node used for auto visibility classification.
final
hashCode int
The hash code for this object.
no setterinherited
meshAnnotations List<VrmFirstPersonMeshAnnotation>
Mesh annotation entries.
final
raw Map<String, Object?>
Raw first-person object, preserved.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
typeForNode(int node) VrmFirstPersonMeshAnnotationType
Returns the visibility annotation for node, defaulting to auto.

Operators

operator ==(Object other) bool
The equality operator.
inherited