VrmHumanoid class final
VRM humanoid mapping.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
humanBones
→ Map<
VrmHumanoidBone, VrmHumanBone> -
Bone assignments by semantic humanoid bone.
final
-
raw
→ Map<
String, Object?> -
Raw humanoid object, preserved.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
nodeFor(
VrmHumanoidBone bone) → int? -
Returns the glTF node assigned to
bone, if present. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited