VrmHumanoidRetargeter class abstract interface

Retargets one VRMA humanoid bone pose onto a destination VRM humanoid bone.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retargetBone({required VrmHumanoidBone bone, required GltfNodePose sourcePose, required GltfNode sourceRestNode, required List<double> sourceRestWorldRotation, required GltfNode destinationRestNode, required List<double> destinationRestWorldRotation, required double hipsTranslationScale}) VrmRetargetedBonePose
Converts sourcePose from the source rest frame to the destination rest frame.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited