VrmMetaModification enum
VRM meta modification permission.
Values
- prohibited → const VrmMetaModification
-
Modification is prohibited.
const VrmMetaModification('prohibited') - allowModification → const VrmMetaModification
-
Modification is allowed.
const VrmMetaModification('allowModification') - allowModificationRedistribution → const VrmMetaModification
-
Modification and redistribution are allowed.
const VrmMetaModification('allowModificationRedistribution')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specName → String
-
Raw VRM spec name.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VrmMetaModification> - A constant List of the values in this enum, in order of their declaration.