GltfNode class final
Parsed glTF node.
Properties
- camera → int?
-
Referenced camera index, if any.
final
-
children
→ List<
int> -
Child node indices.
final
-
extensions
→ Map<
String, Object?> -
Unknown or known node extensions, preserved.
final
- extras → Object?
-
Node extras, preserved.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
glTF node index.
final
- matrix → VrmMatrix4?
-
Local matrix transform, when the node uses matrix form.
final
- mesh → int?
-
Referenced mesh index, if any.
final
- name → String?
-
Optional glTF node name.
final
- nodeConstraint → VrmNodeConstraint?
-
VRMC_node_constraint metadata, when present.
final
-
restRotation
→ List<
double> -
Rest local rotation after applying matrix fallback.
latefinal
-
restScale
→ List<
double> -
Rest local scale after applying matrix fallback.
latefinal
- restTransform → VrmMatrix4
-
Rest local transform.
latefinal
-
restTranslation
→ List<
double> -
Rest local translation after applying matrix fallback.
latefinal
-
rotation
→ List<
double> -
Local rotation quaternion, defaulting to
[0, 0, 0, 1].final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scale
→ List<
double> -
Local scale, defaulting to
[1, 1, 1].final - skin → int?
-
Referenced skin index, if any.
final
-
translation
→ List<
double> -
Local translation, defaulting to
[0, 0, 0].final -
weights
→ List<
double> -
Initial morph target weights for this node.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited