Vrm0Humanoid class final
Legacy VRM 0.x humanoid configuration.
Properties
- armStretch → double?
-
Unity humanoid arm-stretch setting.
final
- feetSpacing → double?
-
Unity humanoid feet-spacing setting.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasTranslationDoF → bool?
-
Whether the legacy Unity humanoid allows translation degrees of freedom.
final
-
humanBones
→ List<
Vrm0HumanBone> -
Humanoid bone assignments in source array order.
final
- legStretch → double?
-
Unity humanoid leg-stretch setting.
final
- lowerArmTwist → double?
-
Unity humanoid lower-arm twist setting.
final
- lowerLegTwist → double?
-
Unity humanoid lower-leg twist setting.
final
-
raw
→ Map<
String, Object?> -
Original legacy humanoid JSON object.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- upperArmTwist → double?
-
Unity humanoid upper-arm twist setting.
final
- upperLegTwist → double?
-
Unity humanoid upper-leg twist setting.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited