VrmFirstPersonMeshAnnotationType enum
VRM first-person mesh annotation type.
Values
- thirdPersonOnly → const VrmFirstPersonMeshAnnotationType
-
Visible only in third person.
const VrmFirstPersonMeshAnnotationType('thirdPersonOnly') - firstPersonOnly → const VrmFirstPersonMeshAnnotationType
-
Visible only in first person.
const VrmFirstPersonMeshAnnotationType('firstPersonOnly') - both → const VrmFirstPersonMeshAnnotationType
-
Visible in both first and third person.
const VrmFirstPersonMeshAnnotationType('both') - auto → const VrmFirstPersonMeshAnnotationType
-
Implementation should infer from head skinning.
const VrmFirstPersonMeshAnnotationType('auto')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specName → String
-
Raw VRM spec name.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromSpecName(
String? name) → VrmFirstPersonMeshAnnotationType - Looks up an annotation type by raw spec name.
Constants
-
values
→ const List<
VrmFirstPersonMeshAnnotationType> - A constant List of the values in this enum, in order of their declaration.